@@ -23,7 +23,6 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
 */
-/* $XFree86: xc/lib/font/util/utilbitmap.c,v 1.4 2001/01/17 19:43:34 dawes Exp $ */
 
 /*
  * Author:  Keith Packard, MIT X Consortium
@@ -32,6 +31,7 @@ in this Software without prior written authorization from The Open Group.
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+#include "libxfontint.h"
 #include <X11/fonts/fontmisc.h>
 
 /* Utility functions for reformating font bitmaps */
@@ -107,7 +107,7 @@ FourByteSwap(unsigned char *buf, int nbytes)
 {
     unsigned char c;
 
-    for (; nbytes > 0; nbytes -= 4, buf += 4) 
+    for (; nbytes > 0; nbytes -= 4, buf += 4)
     {
 	c = buf[0];
 	buf[0] = buf[3];
@@ -123,8 +123,8 @@ FourByteSwap(unsigned char *buf, int nbytes)
  */
 
 int
-RepadBitmap (char *pSrc, char *pDst, 
-	     unsigned int srcPad, unsigned int dstPad, 
+RepadBitmap (char *pSrc, char *pDst,
+	     unsigned int srcPad, unsigned int dstPad,
 	     int width, int height)
 {
     int	    srcWidthBytes,dstWidthBytes;
@@ -132,33 +132,33 @@ RepadBitmap (char *pSrc, char *pDst,
     char    *pTmpSrc,*pTmpDst;
 
     switch (srcPad) {
-    case 1:	
+    case 1:
 	srcWidthBytes = (width+7)>>3;
 	break;
     case 2:
 	srcWidthBytes = ((width+15)>>4)<<1;
 	break;
-    case 4:	
+    case 4:
 	srcWidthBytes = ((width+31)>>5)<<2;
 	break;
-    case 8:	
-	srcWidthBytes = ((width+63)>>6)<<3; 
+    case 8:
+	srcWidthBytes = ((width+63)>>6)<<3;
 	break;
     default:
 	return 0;
     }
     switch (dstPad) {
-    case 1:	
+    case 1:
 	dstWidthBytes = (width+7)>>3;
 	break;
     case 2:
 	dstWidthBytes = ((width+15)>>4)<<1;
 	break;
-    case 4:	
+    case 4:
 	dstWidthBytes = ((width+31)>>5)<<2;
 	break;
-    case 8:	
-	dstWidthBytes = ((width+63)>>6)<<3; 
+    case 8:
+	dstWidthBytes = ((width+63)>>6)<<3;
 	break;
     default:
 	return 0;
